pub fn render(args: Args) -> Result<String, String>
Renders hr-shape output for a parsed argument struct without writing to stdout.
hr-shape
Returns an error string if font loading, input loading, or shaping fails.