pub fn run_from_args<I, T>(args: I) -> Result<String, String>Expand description
Parses hr-shape arguments from an iterator and returns the rendered output.
If -o/--output-file is present, this also writes the rendered output to that file.
Errors
Returns an error string if argument parsing, shaping, or requested file output fails.